@@ -43,9 +43,8 @@ CoverList* cover_create(void);
 
 /*
  * Destroy a CoverList object.
- * After freeing the CoverList we assign NULL to cover.
  */
-void cover_destroy(CoverList** cover);
+void cover_destroy(CoverList* cover);
 
 /*
  * Add a file:line to the CoverList; will create CoverNode for file, if it
