@@ -2,10 +2,11 @@ package Devel::QuickCover;
 
 use strict;
 use warnings;
+
 use XSLoader;
 use Data::Dumper;
 
-our $VERSION = '0.200000';
+our $VERSION = '0.200001';
 
 XSLoader::load( 'Devel::QuickCover', $VERSION );
 
@@ -67,7 +68,7 @@ Devel::QuickCover - Quick & dirty code coverage for Perl
 
 =head1 VERSION
 
-Version 0.200000
+Version 0.200001
 
 =head1 SYNOPSIS
 
@@ -98,7 +99,7 @@ in the coverage information.
     Devel::QuickCover::end();
     baz();
 
-For now, we support calling start() only once.
+For now, we support calling C<start()> only once.
 
 =head1 AUTHORS
 
